==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/HTTPCompressionPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class HTTPCompressionPolicyFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.HTTPCompressionPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.HTTPCompressionPolicyFluent<A>{
  public HTTPCompressionPolicyFluentImpl() {
  }
  public HTTPCompressionPolicyFluentImpl(io.fabric8.openshift.api.model.operator.v1.HTTPCompressionPolicy instance) {
    this.withMimeTypes(instance.getMimeTypes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> mimeTypes = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToMimeTypes(java.lang.Integer index,java.lang.String item) {
    if (this.mimeTypes == null) {this.mimeTypes = new java.util.ArrayList<java.lang.String>();}
    this.mimeTypes.add(index, item);
    return (A)this;
  }
  public A setToMimeTypes(java.lang.Integer index,java.lang.String item) {
    if (this.mimeTypes == null) {this.mimeTypes = new java.util.ArrayList<java.lang.String>();}
    this.mimeTypes.set(index, item); return (A)this;
  }
  public A addToMimeTypes(java.lang.String... items) {
    if (this.mimeTypes == null) {this.mimeTypes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.mimeTypes.add(item);} return (A)this;
  }
  public A addAllToMimeTypes(java.util.Collection<java.lang.String> items) {
    if (this.mimeTypes == null) {this.mimeTypes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.mimeTypes.add(item);} return (A)this;
  }
  public A removeFromMimeTypes(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.mimeTypes!= null){ this.mimeTypes.remove(item);}} return (A)this;
  }
  public A removeAllFromMimeTypes(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.mimeTypes!= null){ this.mimeTypes.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getMimeTypes() {
    return this.mimeTypes;
  }
  public java.lang.String getMimeType(java.lang.Integer index) {
    return this.mimeTypes.get(index);
  }
  public java.lang.String getFirstMimeType() {
    return this.mimeTypes.get(0);
  }
  public java.lang.String getLastMimeType() {
    return this.mimeTypes.get(mimeTypes.size() - 1);
  }
  public java.lang.String getMatchingMimeType(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: mimeTypes) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingMimeType(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: mimeTypes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withMimeTypes(java.util.List<java.lang.String> mimeTypes) {
    if (mimeTypes != null) {this.mimeTypes = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : mimeTypes){this.addToMimeTypes(item);}} else { this.mimeTypes = null;} return (A) this;
  }
  public A withMimeTypes(java.lang.String... mimeTypes) {
    if (this.mimeTypes != null) {this.mimeTypes.clear();}
    if (mimeTypes != null) {for (java.lang.String item :mimeTypes){ this.addToMimeTypes(item);}} return (A) this;
  }
  public java.lang.Boolean hasMimeTypes() {
    return mimeTypes != null && !mimeTypes.isEmpty();
  }
  public A addNewMimeType(java.lang.String arg0) {
    return (A)addToMimeTypes(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPCompressionPolicyFluentImpl that = (HTTPCompressionPolicyFluentImpl) o;
    if (mimeTypes != null ? !mimeTypes.equals(that.mimeTypes) :that.mimeTypes != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mimeTypes,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/HTTPCompressionPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class HTTPCompressionPolicyFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.HTTPCompressionPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.HTTPCompressionPolicyFluent<A>{
  public HTTPCompressionPolicyFluentImpl() {
  }
  public HTTPCompressionPolicyFluentImpl(io.fabric8.openshift.api.model.operator.v1.HTTPCompressionPolicy instance) {
    this.withMimeTypes(instance.getMimeTypes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> mimeTypes = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToMimeTypes(java.lang.Integer index,java.lang.String item) {
    if (this.mimeTypes == null) {this.mimeTypes = new java.util.ArrayList<java.lang.String>();}
    this.mimeTypes.add(index, item);
    return (A)this;
  }
  public A setToMimeTypes(java.lang.Integer index,java.lang.String item) {
    if (this.mimeTypes == null) {this.mimeTypes = new java.util.ArrayList<java.lang.String>();}
    this.mimeTypes.set(index, item); return (A)this;
  }
  public A addToMimeTypes(java.lang.String... items) {
    if (this.mimeTypes == null) {this.mimeTypes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.mimeTypes.add(item);} return (A)this;
  }
  public A addAllToMimeTypes(java.util.Collection<java.lang.String> items) {
    if (this.mimeTypes == null) {this.mimeTypes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.mimeTypes.add(item);} return (A)this;
  }
  public A removeFromMimeTypes(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.mimeTypes!= null){ this.mimeTypes.remove(item);}} return (A)this;
  }
  public A removeAllFromMimeTypes(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.mimeTypes!= null){ this.mimeTypes.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getMimeTypes() {
    return this.mimeTypes;
  }
  public java.lang.String getMimeType(java.lang.Integer index) {
    return this.mimeTypes.get(index);
  }
  public java.lang.String getFirstMimeType() {
    return this.mimeTypes.get(0);
  }
  public java.lang.String getLastMimeType() {
    return this.mimeTypes.get(mimeTypes.size() - 1);
  }
  public java.lang.String getMatchingMimeType(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: mimeTypes) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingMimeType(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: mimeTypes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withMimeTypes(java.util.List<java.lang.String> mimeTypes) {
    if (mimeTypes != null) {this.mimeTypes = new java.util.ArrayList(); for (java.lang.String item : mimeTypes){this.addToMimeTypes(item);}} else { this.mimeTypes = null;} return (A) this;
  }
  public A withMimeTypes(java.lang.String... mimeTypes) {
    if (this.mimeTypes != null) {this.mimeTypes.clear();}
    if (mimeTypes != null) {for (java.lang.String item :mimeTypes){ this.addToMimeTypes(item);}} return (A) this;
  }
  public java.lang.Boolean hasMimeTypes() {
    return mimeTypes != null && !mimeTypes.isEmpty();
  }
  public A addNewMimeType(java.lang.String arg0) {
    return (A)addToMimeTypes(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPCompressionPolicyFluentImpl that = (HTTPCompressionPolicyFluentImpl) o;
    if (mimeTypes != null ? !mimeTypes.equals(that.mimeTypes) :that.mimeTypes != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mimeTypes,  additionalProperties,  super.hashCode());
  }
  
}
